package DZPL;

=head1 LINKS

L<DZPL::Test::_UPLEV>

L<DZPL::Test::_UPLEV/"A subsec">

L<DZPL::Test::Module::_DUMMY>

L<Test::Module::NoMod>

L<Pod::Weaver>

=cut

1;
